==> hoteldruid-mod-de_1.3.2-1.tar.gz: de/storia_soldi.php <==
<?php

switch ($messaggio) {

case "Vedi le modifiche":  			$messaggio = "&Auml;nderungen anzeigen"; break;
case "dal":  					$messaggio = "von"; break;
case "al":  					$messaggio = "zu"; break;
case "Senza colori":  				$messaggio = "Ohne Farben"; break;
case "Con colori":  				$messaggio = "Mit Farben"; break;
case "fino al":  				$messaggio = "zu"; break;
case "Storia delle entate e uscite delle prenotazioni inserite nel":	$messaggio = "Zahlungshistorie f&uuml;r Reservierungen eingegeben in"; break;
case "Dati della prenotazione":  		$messaggio = "Reservierungsdatum"; break;
case "Pagato prima":  				$messaggio = "Bezahlt vor"; break;
case "Pagato dopo":  				$messaggio = "Bezahlt nach"; break;
case "Saldo":  					$messaggio = "Differenz"; break;
case "Data_della modifica":  			$messaggio = "&Auml;nderungsdatum"; break;
case "Cognome_cliente":  			$messaggio = "Kunde_Nachname"; break;
case "Data_iniziale":  				$messaggio = "Startdatum"; break;
case "Data_finale":  				$messaggio = "Enddatum"; break;
case "TOTALE":  				$messaggio = "GESAMT"; break;
case "Torna indietro":  			$messaggio = "Zur&uuml;ck"; break;
case "Trasferito in cassa":  			$messaggio = "&Uuml;bertragen in die Kasse"; break;
case "RESTO":  					$messaggio = "REST"; break;
case "pagine":  				$messaggio = "Seiten"; break;
case "Cliente":  				$messaggio = "Kunde"; break;
case "Utente":  				$messaggio = "Benutzer"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\"><b>azzerare</b></div> tutte le entrate e le uscite delle prenotazioni e i soldi trasferiti in cassa del":	$messaggio = "Are you sure you want to <div style=\"display: inline; color: red;\"><b>delete</b></div> all reservations payments and money transferred in cash box of"; break;
case "SI":  					$messaggio = "JA"; break;
case "NO":  					$messaggio = "Nein"; break;
case "Azzera entrate e uscite prenotazioni":  	$messaggio = "Alle Reservierungszahlungen l&ouml;schen"; break;
case "Metodo":  				$messaggio = "Zahlungsweise"; break;
case "Vedi solo le entrate-uscite":  		$messaggio = "Nur Zahlungen anzeigen"; break;
case "con metodo":  				$messaggio = "mit Zahlungsweise"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-de_3.0.8-1.tar.gz: de/storia_soldi.php <==
<?php

switch ($messaggio) {

case "Vedi le modifiche":  			$messaggio = "&Auml;nderungen anzeigen"; break;
case "dal":  					$messaggio = "von"; break;
case "al":  					$messaggio = "zu"; break;
case "Senza colori":  				$messaggio = "Ohne Farben"; break;
case "Con colori":  				$messaggio = "Mit Farben"; break;
case "fino al":  				$messaggio = "zu"; break;
case "Storia delle entate e uscite delle prenotazioni inserite nel":	$messaggio = "Zahlungshistorie f&uuml;r Reservierungen eingegeben in"; break;
case "Dati della prenotazione":  		$messaggio = "Reservierungsdatum"; break;
case "Pagato prima":  				$messaggio = "Bezahlt vor"; break;
case "Pagato dopo":  				$messaggio = "Bezahlt nach"; break;
case "Saldo":  					$messaggio = "Differenz"; break;
case "Data_della modifica":  			$messaggio = "&Auml;nderungsdatum"; break;
case "Cognome_cliente":  			$messaggio = "Kunde_Nachname"; break;
case "Data_iniziale":  				$messaggio = "Startdatum"; break;
case "Data_finale":  				$messaggio = "Enddatum"; break;
case "TOTALE":  				$messaggio = "GESAMT"; break;
case "Torna indietro":  			$messaggio = "Zur&uuml;ck"; break;
case "Trasferito in cassa":  			$messaggio = "&Uuml;bertragen in die Kasse"; break;
case "pagine":  				$messaggio = "Seiten"; break;
case "Cliente":  				$messaggio = "Kunde"; break;
case "Utente":  				$messaggio = "Benutzer"; break;
case "SI":  					$messaggio = "JA"; break;
case "NO":  					$messaggio = "Nein"; break;
case "Azzera entrate e uscite prenotazioni":  	$messaggio = "Alle Reservierungszahlungen l&ouml;schen"; break;
case "Metodo":  				$messaggio = "Zahlungsweise"; break;
case "Vedi solo le entrate-uscite":  		$messaggio = "Nur Zahlungen anzeigen"; break;
case "con metodo":  				$messaggio = "mit Zahlungsweise"; break;
case "N°":  					$messaggio = "N."; break;
case "Id":  					$messaggio = "Id"; break;
case "Storico Entrate":  			$messaggio = "Payments History"; break;
case "RESTO":  					$messaggio = "REST"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\"><b>azzerare</b></div> tutte le entrate e le uscite delle prenotazioni e i soldi trasferiti in cassa del":	$messaggio = "Are you sure you want to <div style=\"display: inline; color: red;\"><b>delete</b></div> all reservations payments and money transferred in cash box of"; break;
case "Note":  					$messaggio = "Notes"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
